Yeah, cause the weather is sunny.

As usual, a diff from GIT's develop branch.

- Fixed: rouget's shipping model use shipping contact adress if defined and if used

Eldy/Regis, do you plan to only keep one model uptodate, or there are no plans to change this actually ?

Have fun,
CF/Graveen

>From 5d4ac6a906d49202d82499bbdeeb3006525d103a Mon Sep 17 00:00:00 2001
From: graveen <[email protected]>
Date: Sun, 25 Sep 2011 18:13:18 +0200
Subject: [PATCH] - Fixed: rouget's shipping model use shipping contact adress 
if defined and if used

---
 .../pdf/pdf_expedition_rouget.modules.php          |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git 
a/htdocs/includes/modules/expedition/pdf/pdf_expedition_rouget.modules.php 
b/htdocs/includes/modules/expedition/pdf/pdf_expedition_rouget.modules.php
index 9de72da..014b8fc 100644
--- a/htdocs/includes/modules/expedition/pdf/pdf_expedition_rouget.modules.php
+++ b/htdocs/includes/modules/expedition/pdf/pdf_expedition_rouget.modules.php
@@ -444,14 +444,14 @@ Class pdf_expedition_rouget extends ModelePdfExpedition {
             $pdf->MultiCell(80, 4, $carac_emetteur, 0, 'L');
 
 
             // If CUSTOMER contact defined, we use it
             $usecontact = false;
-            $arrayidcontact = $object->getIdContact('external', 'CUSTOMER');
+            $arrayidcontact = $object->getIdContact('external', 'SHIPPING');
             if (count($arrayidcontact) > 0) {
                 $usecontact = true;
                 $result = $object->fetch_contact($arrayidcontact[0]);
             }
-
+            
             // Recipient name
             if (!empty($usecontact)) {
                 // On peut utiliser le nom de la societe du contact
@@ -444,14 +444,14 @@ Class pdf_expedition_rouget extends ModelePdfExpedition {
 
 
-            // If CUSTOMER contact defined, we use it
+            // If SHIPPING contact defined, we use it
             $usecontact = false;
-- 
1.7.4.msysgit.0

_______________________________________________
Dolibarr-dev mailing list
[email protected]
https://lists.nongnu.org/mailman/listinfo/dolibarr-dev

Répondre à